"use strict";
// Copyright (c) Mito
// Distributed under the terms of the Modified BSD License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
// import css
require("../../../../css/margins.css");
require("../../../../css/filter_modal.css");
var SortDirection;
(function (SortDirection) {
    SortDirection["ASCENDING"] = "ascending";
    SortDirection["DESCENDING"] = "descending";
    SortDirection["NONE"] = "none";
})(SortDirection = exports.SortDirection || (exports.SortDirection = {}));
/*
    A modal that allows a user to sort a column
*/
class SortCard extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.setSortDirection = (sortDirection) => {
            // if the user toggled the button that was already selected, turn off the sort
            if (sortDirection == this.state.sortDirection) {
                this.setState({
                    sortDirection: SortDirection.NONE
                });
                return;
            }
            // otherwise the user selected a new direction, so set that as the sortDirection
            this.setState({
                sortDirection: sortDirection
            }, () => {
                // then sort the column
                void this.sendSortUpdateMessage();
            });
        };
        this.sendSortUpdateMessage = () => __awaiter(this, void 0, void 0, function* () {
            // sort the columns if the sortDirection is not None
            if (this.state.sortDirection != SortDirection.NONE) {
                const stepID = yield this.props.mitoAPI.sendSortMessage(this.props.selectedSheetIndex, this.props.columnHeader, this.state.sortDirection, this.state.stepID);
                this.setState({ stepID: stepID });
            }
        });
        this.state = {
            sortDirection: SortDirection.NONE,
            stepID: ''
        };
        this.sendSortUpdateMessage = this.sendSortUpdateMessage.bind(this);
        this.setSortDirection = this.setSortDirection.bind(this);
    }
    render() {
        // determine css styling of sort buttons
        const ascendingButtonClass = this.state.sortDirection == SortDirection.ASCENDING ? 'sort-button sort-button-selected' : 'sort-button sort-button-unselected';
        const descendingButtonClass = this.state.sortDirection == SortDirection.DESCENDING ? 'sort-button sort-button-selected' : 'sort-button sort-button-unselected';
        return (react_1.default.createElement("div", null,
            react_1.default.createElement("div", { className: 'filter-modal-section-title' },
                react_1.default.createElement("p", null, " Sort ")),
            react_1.default.createElement("div", { className: "filter-modal-centering-container" },
                react_1.default.createElement("div", { className: 'sort-buttons-div' },
                    react_1.default.createElement("button", { className: ascendingButtonClass, onClick: () => this.setSortDirection(SortDirection.ASCENDING) }, "Ascending"),
                    react_1.default.createElement("button", { className: descendingButtonClass, onClick: () => this.setSortDirection(SortDirection.DESCENDING) }, "Descending")))));
    }
}
exports.default = SortCard;
//# sourceMappingURL=SortCard.js.map